@@ -1,13 +1,14 @@
+"""pyVig Excel Preparation -  A Single Device Cabling Details.
+"""
 
 import pandas as pd
-from .general import drop_empty
-# --------------------------------------------- 
+from .general import *
 
-DEFAULT_CONNECTOR_TYPE = 'straight'  ## other options = 'curved', 'angled'
-DEFAULT_LINE_COLOR = 'blue'
-DEFAULT_LINE_WT = 3
-DEFAULT_LINE_PATTERN = 1
-# --------------------------------------------- 
+
+
+# ----------------------------------------------------------------------------------------------------
+# A single device cabling details.
+# ----------------------------------------------------------------------------------------------------
 class ADevCablings():
 	"""A single Device Cabling details
 	"""	
@@ -21,9 +22,7 @@ class ADevCablings():
 		self.self_device = self_device
 		self.cablings = {}
 		self.cablings['a_device'] = []
-		self.cablings['a_device_port'] = []
 		self.cablings['b_device'] = []
-		self.cablings['dev_b_port'] = []
 		self.cabling_mandatory_columns = set(self.cablings.keys())
 		self.cabling_optional_columns = {'connector_type', 'color', 'weight', 'pattern'}
 		self.connector_type, self.color, self.weight, self.pattern = DEFAULT_CONNECTOR_TYPE, DEFAULT_LINE_COLOR, DEFAULT_LINE_WT, DEFAULT_LINE_PATTERN 
@@ -41,8 +40,8 @@ class ADevCablings():
 		"""
 		mandatory_col_maps = {
 			'b_device': 'nbr_hostname' ,
-			'a_device_port': 'interface',
-			'dev_b_port': 'nbr_interface',
+			'aport': 'interface',
+			'bport': 'nbr_interface',
 		}
 		#
 		for k in self.cablings:
