@@ -1,23 +1,51 @@
-
+"""database activities"""
 
 # -----------------------------------------------------------------------------------
 import pandas as pd
 
 from pyVig.maths import df_with_slops_and_angles
+from .general import *
+
 # -----------------------------------------------------------------------------------
 
+# ----------------------------------------------------------------------------------------------------
+
 class Data():
 	'''
 	Parent class defining device and connectors.
 	'''
 
-	def __init__(self, data_file):
+	def __init__(self, **kwargs):
 		"""Initialize the object
 
 		Args:
 			data_file (str): file name of excel database containing devices and cabling details.
 		"""		
-		self.data_file = data_file
+		self.kwargs = kwargs
+		self.add_kwargs_attributes()
+		self.data_file = kwargs['data_file']
+
+	def add_kwargs_attributes(self):
+		"""adds all keyword arguments as object attributes
+		"""		
+		for k, v in self.kwargs.items():
+			self.add_attribute(k, v)
+
+	def add_optional_columnnames_attributes(self):
+		"""adds default optional columns as object attributes
+		"""		
+		for k, v in self.optional_columns.items():
+			self.add_attribute(k, v)
+
+	def add_attribute(self, attr_name, attr_value):
+		"""adds an attribute to object instance
+
+		Args:
+			attr_name (str): attribute name
+			attr_value (str): attribute value
+		"""		
+		if attr_name:
+			self.__dict__[attr_name] = attr_value
 
 	def read(self, sheet_name):
 		"""read data from given excel sheet and set dataframe for the object.
@@ -25,7 +53,27 @@ class Data():
 		Args:
 			sheet_name (str): Excel sheet name
 		"""		
-		self.df = pd.read_excel(self.data_file, sheet_name=sheet_name).fillna("")
+		try:
+			self.df = pd.read_excel(self.data_file, sheet_name=sheet_name).fillna("")
+		except Exception as e:
+			print(f'Critical:\tMandatory sheet "{sheet_name}" missing or invalid, Please check data')
+			quit("")
+
+	def verify_mandatory_declared_cols_availabilty(self, declared=[]):
+		"""verifies if mandatory and declared columns (cols_to_merge) are available in provided database.
+		Raise error if unavailable any.
+
+		Args:
+			declared (list, optional): list of extra declared columns (if any). Defaults to [].
+		"""		
+		missing_cols = set()
+		self.cols_to_check.extend(declared)
+		for col in self.cols_to_check:
+			if col not in self.df.columns:
+				missing_cols.add(col)
+		if missing_cols:
+			print(f"Critical:\tMandatory and/or Declared column(s) {missing_cols} missing or invalid, Please check data")
+			quit()
 
 
 # -----------------------------------------------------------------------------------
@@ -34,42 +82,43 @@ class Data():
 class DeviceData(Data):
 	"""Devices Data Object Building
 	"""		
+	format_columns = {	'iconWidth': 2.5, 
+						'iconHeight': 1,
+	}
 
-	def __init__(self, 
-		data_file, 
-		sheet_name,
-		x="x",
-		y="y",
-		stencil_colname=None,
-		device_type_colname=None,
-		default_stencil=None,
-		):
-		super().__init__(data_file)
-		self.x = x
-		self.y = y
-		self.stencil = stencil_colname
-		self.dev_type = device_type_colname
-		self.default_stencil = default_stencil
-		self.read(sheet_name)
+	optional_columns = {'stencil': DEFAULT_STENCIL,
+						'item': None,
+	}
+	x = 'x-axis'
+	y = 'y-axis'
+	default_stencil = None
+	sheet_name = 'Devices'
 
-	def read(self, sheet_name):
-		"""read data from given excel sheet containing device data and set dataframe for the object.
+	def __init__(self, **kwargs):
+		super().__init__(**kwargs)
+		self.add_format_columnnames_attributes()
+		self.add_optional_columnnames_attributes()
+		self.read(self.sheet_name)		
+		self.cols_to_check = [self.x, self.y, 'hostname']
+		self.verify_mandatory_declared_cols_availabilty(self._declared_cols())
 
-		Args:
-			sheet_name (str): Excel sheet name
+	def _declared_cols(self):
+		"""get a list of declared columns from input 'cols_to_merge' if defined.
+		This is to check the existance of those columns in database further
+
+		Returns:
+			list: list of declared columns (to be merged)
 		"""		
-		super().read(sheet_name)
-		self.add_missing_cols()
+		if self.kwargs.get('cols_to_merge'):
+			return self.kwargs['cols_to_merge']
+		return []
 
-	def add_missing_cols(self):
-		"""add the additional blank columns to dataframe if missing.
+	def add_format_columnnames_attributes(self):
+		"""add default format columns {iconWidth, iconHeight} as object attributes
 		"""		
-		if not self.stencil:
-			self.stencil = "stencil"
-			self.df[self.stencil] = ""
-		if not self.dev_type:
-			self.dev_type = "dev_type"
-			self.df[self.dev_type] = ""
+		for k, v in self.format_columns.items():
+			self.add_attribute(k, v)
+
 
 	def add_description(self, columns_to_merge):
 		"""add a description column to dataframe, which will be output of merged data of provided columns
@@ -86,15 +135,15 @@ class DeviceData(Data):
 			try:
 				cols.append(self.df[x])
 			except:
-				print(f"column `{x}` is missing in input file")
+				print(f"Warning:\t\tcolumn `{x}` is missing in input file")
 		try:
 			self.df['description'] = self.df.hostname
 		except:
-			raise ValueError("Missing mandatory column `hostname` ")
+			raise ValueError("Critical:\tMissing mandatory column `hostname` ")
 
 		for col in cols:
 			if col.empty:  continue
-			self.df.description += "\n"+ col.str.strip().fillna("invalid datatype")
+			self.df.description += "\n"+ col.astype(str).str.strip().fillna("invalid datatype")
 
 
 # -----------------------------------------------------------------------------------
@@ -117,7 +166,7 @@ def merged_df_on_hostname(devices_df, cablemtx_df, hostname_col_hdr, sortby):
 	try:
 		cablemtx_df['hostname'] = cablemtx_df[hostname_col_hdr]
 	except:
-		raise ValueError(f"Missing mandatory column `{hostname_col_hdr}`")
+		raise ValueError(f"Critical:\tMissing mandatory column `{hostname_col_hdr}`")
 	cablemtx_df = cablemtx_df.reset_index()
 	return pd.merge(cablemtx_df, devices_df, 
 		on=["hostname",], 
@@ -129,61 +178,31 @@ class CableMatrixData(Data):
 	"""Cabling Data Object Building
 	"""		
 
-	def __init__(self, 
-		data_file, 
-		sheet_name,
-		a_device_colname, 
-		b_device_colname,
-		a_device_port_colname=None,
-		connector_type_colname=None,
-		cable_color_colname=None,
-		cable_weight_colname=None,
-		cable_line_pattern_colname=None,
-		):
-		super().__init__(data_file)
-		self.dev_a = a_device_colname
-		self.dev_b = b_device_colname
-		self.dev_a_port = a_device_port_colname
-		self.conn_type = connector_type_colname
-		self.color = cable_color_colname		
-		self.weight = cable_weight_colname
-		self.pattern = cable_line_pattern_colname
-		self.read(sheet_name)
+	optional_columns = {'connector_type': DEFAULT_CONNECTOR_TYPE,
+						'color': DEFAULT_LINE_COLOR,
+						'weight': DEFAULT_LINE_WT,
+						'pattern': DEFAULT_LINE_PATTERN,
+						'aport': "",
+	}
+	sheet_name = 'Cablings'
 
-	def read(self, sheet_name):
-		"""read data from given excel sheet containing cabling data and set dataframe for the object.
+	def __init__(self, **kwargs):
+		self.dev_a = 'a_device'
+		self.dev_b = 'b_device'
+		super().__init__(**kwargs)
+		self.add_optional_columnnames_attributes()
+		# self.add_kwargs_attributes()
+		self.read(self.sheet_name)
+		self.cols_to_check = [self.dev_a, self.dev_b]
+		self.verify_mandatory_declared_cols_availabilty()
 
-		Args:
-			sheet_name (str): Excel sheet name
-		"""		
-		super().read(sheet_name)
-		self.add_missing_cols()
-
-	def add_missing_cols(self):
-		"""add the additional blank columns to dataframe if missing.
-		"""		
-		if not self.dev_a_port:
-			self.dev_a_port = "a_device_port"
-			self.df[self.dev_a_port] = ""
-		if not self.conn_type:
-			self.conn_type = "conn_type"
-			self.df[self.conn_type] = ""
-		if not self.color:
-			self.color = "color"
-			self.df[self.color] = ""
-		if not self.weight:
-			self.weight = "weight"
-			self.df[self.weight] = ""
-		if not self.pattern:
-			self.pattern = "pattern"
-			self.df[self.pattern] = ""
 
 	# optional
 	def filter_eligible_cables_only(self):
 		"""optional filter: filters DataFrame for the column `include` with values as `y`
 		"""				
 		if "include" in self.df.columns:
-			self.df = self.df[ self.df.include == "y"]
+			self.df = self.df[ self.df.include != ""]
 
 	# optional
 	def filter(self, **kwargs):
