@@ -15,11 +15,11 @@ from pyVig.common import get_filename
 #  VisioObject class
 # ------------------------------------------------------------------------------
 class VisioObject():
-	# """Creates a Visio Object. 
-	# Param : stencils  - object stancils
-	# example : oVis = VisioObject(stencils=[stencil1, stencil2])
-	# 		  stencil1 and stencil2 are two different stencils.
-	# """
+	"""Creates a Visio Object. 
+
+	Returns:
+		_type_: _description_
+	"""	
 
 	# stencils dictionary
 	stn = {}
@@ -59,8 +59,12 @@ class VisioObject():
 
 	# context end
 	def __exit__(self, exc_type, exc_value, tb):
-		self._saveVisio(self.outputFile)
-		self._closeVisio()
+		save_success = self._saveVisio(self.outputFile)
+		if save_success:
+			self._closeVisio()
+		else:
+			print(f"Information:\tVisio file save did not happen, please save and close visio manually")
+		#
 		if exc_type is not None:
 			traceback.print_exception(exc_type, exc_value, tb)
 
@@ -74,47 +78,76 @@ class VisioObject():
 
 	# save visio output file
 	def _saveVisio(self, file):
-		try: self.doc.SaveAs(file)
-		except: pass
+		try: 
+			print(f"Information:\tattempting to save file as {file}..")
+			self.doc.SaveAs(file)
+			return True
+		except: 
+			print(f"Warning:\t\tFiles auto save as {file} not working, please save file manually")
+			return False
 
 	# close visio application
 	def _closeVisio(self):
 		try:
+			print(f"Information:\tattempting to close/quite visio ")
 			self.doc.Close()
 			self.visio.Quit()
 		except:
-			pass
+			print(f"Warning:\t\tVisio application failed, please close manually")
 
 	# Internal use only: starts a new Visio Application
 	@property
 	def _startVisio(self):
 		try:
+			print(f"Information:\tstarting visio application..", end='\t')
 			self.visio = win32com.client.Dispatch("Visio.Application")
-		except:
+			print(f"success..",)
+		except Exception as e:
+			print(f"fail..",)
+			print(f"Critical:\tVisio application load failed, retry after clearing temp, verify macros all allowed with vBA access, verify visio application installation..",)
+			print(f"Debug:\t\t{e}",)
 			self.visio = None
 
 	# Internal use only: Open a blank visio page inside opened Visio Application
 	@property
 	def _openBlankVisioDoc(self):
-		self.doc = self.visio.Documents.Add("")
+		try:
+			print(f"Information:\tadding a new blank page on visio application..", end='\t')
+			self.doc = self.visio.Documents.Add("")
+			print(f"success..",)
+		except Exception as e:
+			print(f"fail..",)
+			print(f"Critical:\tadding a new blank page on visio application failed..",)
 
 	def insert_new_page(self, name=None):
 		self.page_number += 1
-		self.page = self.doc.Pages.Add()
-		self.page = self.doc.Pages.Item(self.page_number)
-		if name: self.page.Name = name
+		try:
+			print(f"Information:\tappending a new page on visio application..", end='\t')
+			self.page = self.doc.Pages.Add()
+			self.page = self.doc.Pages.Item(self.page_number)
+			if name: 
+				self.page.Name = name
+				print(f"renamed to {name}..", end='\t')
+			print(f"success..",)
+		except Exception as e:
+			print(f"fail..",)
+			print(f"Critical:\tappending a new page on visio application failed..",)
 
 	# Return item from Stencil
 	def _selectItemfromStencil(self, item, stencil):
-		return self.stn[stencil].Masters.Item(item)
+		try:
+			return self.stn[stencil].Masters.Item(item)
+		except:
+			print(f"Error:\t\titem `{item}` not found in stencil `{stencil}`.., You may see a text box instead")
 
 	# Drops 'item' on visio page at given position index ( posX and posY )
 	def _dropItemtoPage(self, item, posX, posY):
 		try: 
 			itemProp = self.page.Drop(item, posY, posX)
 			return itemProp
-		except: 
-			pass
+		except Exception as e:
+			print(f"Error:\t\tItem Drop failed for {item}, verify stencil, item icon available in stencil",)
+			print(f"Debug:\t\t{e}",)
 
 	@staticmethod
 	def _border(item, borderLineColor=None, borderLinePattern=None,
@@ -172,10 +205,13 @@ class VisioObject():
 
 	@staticmethod
 	def _resize(item, width, height):
-		if width:
-			item.CellsSRC(visSectionObject, visRowXFormOut, visXFormWidth).FormulaU = f"{width} in"
-		if height:
-			item.CellsSRC(visSectionObject, visRowXFormOut, visXFormHeight).FormulaU = f"{height} in"
+		try:
+			if width:
+				item.CellsSRC(visSectionObject, visRowXFormOut, visXFormWidth).FormulaU = f"{width} in"
+			if height:
+				item.CellsSRC(visSectionObject, visRowXFormOut, visXFormHeight).FormulaU = f"{height} in"
+		except:
+			print(f"Error:\t\tResizing of item {item} not allowed for gaurded stencil items. Match text box size manually")
 
 	# --------------------------------------------------------------------------
 	#  External
@@ -193,9 +229,14 @@ class VisioObject():
 		"""		
 		stencil = stencil.replace("/", "\\")
 		try:
-			return self.visio.Documents.Open(stencil)
-		except:
-			pass
+			print(f"Information:\tattempting to open visio stencil {stencil}..", end='\t')
+			s = self.visio.Documents.Open(stencil)
+			print("success..")
+			return s
+		except Exception as e:
+			print("fail..")
+			print(f"Error:\t\tUnable to open visio stencil {stencil}, verify stencil existance",)
+			print(f"Debug:\t\t{e}",)
 
 	def selectNdrop(self, stencil, item, posX, posY, **format):
 		"""Selects item `item` from provided stencil `stencil` for selected visio object.
@@ -212,12 +253,21 @@ class VisioObject():
 		Returns:
 			iconObject: dropped icon object
 		"""
-		ICON_HEIGHT = 1
-		ICON_WEIGHT = 2.5
+		#
+		defaults = {
+			'iconWidth': 2.5,
+			'iconHeight': 1,
+			# add more as and when need.
+		}
+		#
+		for k, v in defaults.items():
+			if k not in format :
+				format[k] = v
+		#
 		itm = self._selectItemfromStencil(item, stencil)
 		if itm is not None:
 			icon = self._dropItemtoPage(itm, posX, posY)
-			self._format(icon=icon, iconHeight=ICON_HEIGHT, iconWidth=ICON_WEIGHT, **format)
+			self._format(icon=icon, **format)
 			return icon
 
 	def shapeDrow(self, shape, lx, lr, rx, rr, **format):
@@ -292,8 +342,6 @@ class VisioObject():
 class Connector():
 	'''s1_s2_Connector = self.connector()
 	Drops a connector to visio page.
-	param : connector_type = ( eg - straight, curved, default=angled )
-	param : x, u = coordinates where to drop connector (default=0,0)
 	'''
 
 	def __init__(self, visObj, connector_type=None):
@@ -382,7 +430,7 @@ class Connector():
 		try:
 			self.obj.Characters.Text = remarks
 		except:
-			pass
+			print(f"Error:\t\tDescription set for object failed `{remarks}` ")
 
 	def line_color(self, color=None):
 		"""color of a line object
@@ -394,7 +442,8 @@ class Connector():
 
 		Returns:
 			None: None
-		"""		
+		"""	
+		clr = "THEMEGUARD(RGB(255,255,255))"
 		if isinstance(color, str):
 			if color.lower() == "red": clr = "THEMEGUARD(RGB(255,0,0))"
 			if color.lower() == "green": clr = "THEMEGUARD(RGB(0,255,0))"
@@ -408,15 +457,20 @@ class Connector():
 			return None
 		try:
 			self.obj.CellsSRC(visSectionObject, visRowLine, visLineColor).FormulaU = clr
-		except: pass
+		except:
+			pass
+			print(f"Error:\t\tLine color formatting failed, `{visRowLine}`, for color `{color}`")
 
 	def line_weight(self, weight=None):
 		"""set weight/thickness of a line
 
 		Args:
 			weight (int, optional): thickness of line. Defaults to None=1.
-		"""		
-		self.obj.CellsSRC(visSectionObject, visRowLine, visLineWeight).FormulaU = f"{weight} pt"
+		"""
+		try:
+			self.obj.CellsSRC(visSectionObject, visRowLine, visLineWeight).FormulaU = f"{weight} pt"
+		except:
+			pass
 
 	def line_pattern(self, pattern=None):
 		"""set line pattern
@@ -424,8 +478,10 @@ class Connector():
 		Args:
 			pattern (int, optional): pattern number. Defaults to solid line.
 		"""		
-		self.obj.CellsSRC(visSectionObject, visRowLine, visLinePattern).FormulaU = pattern
-
+		try:
+			self.obj.CellsSRC(visSectionObject, visRowLine, visLinePattern).FormulaU = pattern
+		except:
+			pass
 
 # ------------------------------------------------------------------------------
 # A Single Visio Item Class defining its properties and methods.
@@ -434,19 +490,18 @@ class Device():
 	"""A Device Object
 	"""		
 
-	def __init__(self, visObj, item, x, y):
+	def __init__(self, visObj, x, y, **kwargs):
 		"""Initialize Device Object
 
 		Args:
 			visObj (Visio): visio object
-			item (str): Device/Item name
 			x (int): x-coordinate
 			y (int): y-coordinate
 		"""		
 		self.visObj = visObj
-		self.item = item
 		self.x = x
 		self.y = y
+		self.kwargs = kwargs
 
 	def drop_from(self, stencil):
 		"""drop an item from stencil, if item not found in stencil then it will drop a rectangle.
@@ -454,9 +509,12 @@ class Device():
 		Args:
 			stencil (str): stencil name
 		"""		
-		if stencil and self.item:
-			self.obj = self.visObj.selectNdrop(stencil=stencil, 
-				item=self.item, posX=self.y, posY=self.x, textSize=.8)
+		if stencil and self.kwargs['item']:
+			self.obj = self.visObj.selectNdrop(
+				posX=self.y, posY=self.x, 
+				textSize=.8, 
+				**self.kwargs
+			)
 			self.is_rectangle = False
 		else:
 			self.obj = self.visObj.shapeDrow('rectangle', 
@@ -522,21 +580,20 @@ class Device():
 # ------------------------------------------------------------------------------
 # Device class object return by dropping it to given position
 # ------------------------------------------------------------------------------
-def device(stencil, visObj, item, x, y):
+def device(visObj, x, y, **kwargs):
 	"""Drop an item from stencil given to visio object at given x,y co-ordinates.
 
 	Args:
-		stencil (str): stencil name
 		visObj (Visio): Visio Object
-		item (str): name or number of device/item from stencil
 		x (int): x coordinate
 		y (int): y coordinate
+		**kwargs (kwargs): keyword arguments
 
 	Returns:
 		Device: Device Object
 	"""	
-	D = Device(visObj, item, x, y)
-	D.drop_from(stencil)
+	D = Device(visObj, x, y, **kwargs)
+	D.drop_from(kwargs['stencil'])
 	return D
 
 
